MPAthic — mpathic 0.0.1 documentation

# MPAthic

Written by William Ireland, Ammar Tareen, and Justin B. Kinney.

# Under Active Development

MPAthic [1] is a python API and it fits quantitative models to data. Most MPAthic classes take in one or more tabular text files as input and return a tabular text file as output. All input and output files are designed to be human readable. The first line of each tabular text file contains headers describing the contents of each column. All input files are required to have the proper set of columns, which of course depend on the command being executed. By default, input is taken from the standard input and output is written to the standard output.

## Installation

MPAthic can be installed from PyPI using the pip package manager (version 9.0.0 or higher). At the command line:

    pip install mpathic

The code for MPAthic is open source and available on GitHub.

## Quick Start

The following snippets show how to use MPAthic from within python.

    import mpathic as mpa
    mpa.demo()

## Resources

- Tutorial
  - Simulating Data
  - Computing Profiles
  - Quantitative Modeling
- Examples
- Documentation
  - mpa.SimulateLibrary
  - mpa.SimulateSort
  - mpa.ProfileFreq
  - mpa.ProfileMutrate
  - mpa.ProfileInfo
  - mpa.LearnModel
  - mpa.EvaluateModel
  - mpa.ScanModel
  - mpa.demo()

## Contact

For technical assistance or to report bugs, please contact Ammar Tareen.

For more general correspondence, please contact Justin Kinney.

Other links:

- Kinney Lab
- Simons Center for Quantitative Biology
- Cold Spring Harbor Laboratory

## References

[1] | William T. Ireland and Justin B. Kinney (2016) MPAthic: quantitative modeling of sequence-function relationships for massively parallel assays `PDF`.

## Indices and tables

- Index
- Module Index
- Search Page